/***************************************************************************
 ** 
 **  File: readbinex1.c
 **
 **  Description: An example of using the routines in readbin.c.
 **
 **  Date: 8th January 2004
 **
 ***************************************************************************
 ***************************************************************************
 *
 *    Copyright (C) 2004 Scott A. Belmonte
 *    All rights reserved.
 *
 *    Redistribution and use in source and binary forms, with or without 
 *    modification, are permitted provided that the following conditions
 *    are met:
 *
 *    Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 *    Neither the name of the copyright holder nor the names of any
 *    contributors may be used to endorse or promote products derived from
 *    this software without specific prior written permission.
 * 
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
 *    "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 *    LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR 
 *    A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 *    OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, 
 *    SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 *    LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, 
 *    DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY 
 *    THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *    (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
 *    OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ***************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include "readbin.h"

#define WIDTH 625
#define HEIGHT 576

int main()
{
    FILE           *file_p;
    unsigned short *data_p;
    e_swap          swap_bytes;

    /* Allocate memory for data. */
    data_p = (unsigned short *) malloc(sizeof(unsigned short)*WIDTH*HEIGHT);
    if (data_p == NULL)
    {
        fprintf(stderr, "Couldn't allocate memory for data.\n");
        exit(1);
    }

    /* Open example.xxx */
    if ((file_p = fopen("example.xxx", "rb")) == NULL)
    {
        fprintf(stderr, "Error opening file.\n");
        exit(1);
    }

    /* Little-endian file: Work out if we need to swap multibyte sequences */
    if (get_endian() == MACHINE_BIG_ENDIAN)
    {
        swap_bytes = SWAP;
    }
    else
    {
        swap_bytes = DONT_SWAP;
    }

    /* Data start at byte 4100. */
    if (fseek(file_p, 4100, SEEK_SET) != 0)
    {
        fprintf(stderr, "Error seeking in file.\n");
        exit(1);
    }

    /* Read data. */
    if (read_bin_file(data_p, sizeof(unsigned short), WIDTH*HEIGHT, 
                      file_p, swap_bytes) != WIDTH*HEIGHT)
    {
        fprintf(stderr, "Error reading data.\n");
        exit(1);
    }
    
    fclose(file_p);
    return 0;
}
